###########################################################################
# Insert one TMS320C5500 CPU into JTAG chain
# with emulator as parent 
###########################################################################
set DEV0 [ xds add TMS320C5500 $EMU ]

###########################################################################
# Select $DEV0 CPU as target device DEV, to which flash/EEPROM is connected
###########################################################################
set DEV $DEV0

###########################################################################
# CPU clock frequency
###########################################################################
set cpu_clock 20000000
# SYSCLKx by default in VC5502 = cpu_clock / 4
set periph_clock [expr $cpu_clock / 4]

###########################################################################
# for SPI-interfaced FLASH IC's
# set information on CS signal

# CS signal port is IODATA (0x3401 in CPU's IO space)
set cs_port_address 0x3401
# CS signal port is in IO space
set cs_port_mempage 2
# CS signal port width (0 - 8-bit, 1 - 16-bit, 2 - 32-bit)
set cs_port_width 1
# CS signal bit is 0x0010 (GPIO4)
set cs_port_bit 0x0010
# CS signal polarity is 0, active low
set cs_port_polarity 0


###########################################################################
# change this proc according to schematic of your
# board to initialize all of the environment of EEPROM/Flash
# for correct programming
###########################################################################
proc UserInitCPUEnv { dev } {

  upvar 1 flash_type flash_type

  if { $flash_type == 2 } {

    # for SPI EEPROMS - we need configure CS (GPIO4) as output
    # with high level by default
    # thus we need IODIR=0x10; IODATA=0x10;
    # do this through direct access to CPU's address space

    # IODIR = 0x10
    PutShort $dev 0x3400 2 0x10

    # IODATA = 0x10
    PutShort $dev 0x3401 2 0x10

    puts "  GPIO4 (EEPROM's CS pin) is set to output with high level"

    # write 0 CPLD_REG_6 (0x380006 in DATA space (mempage 1))
    # to enable GPIO4->CS
    PutShort $dev 0x380006 1 0

    puts "  CPLD register #6 is set to all zero"

  }

}

###########################################################################
# change this proc according to schematic of your
# board to reset all of the environment of EEPROM/Flash
# for normal operation after programming
###########################################################################
proc UserFinishCPUEnv { dev } {

  upvar 1 flash_type flash_type

  if { $flash_type == 2 } {

    # IODIR = 0
    PutShort $dev 0x3400 2 0

    puts "  All GPIO tristated"

  }

}
